﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;
using Jerid.Eric.DataServer.DataObjects;
using System.Reflection;

public class StationLayer : MapLayerBase
{
    FeatureSourceMarkerOverlay markerOverlay = new FeatureSourceMarkerOverlay(UniqueKey);

    public static readonly string UniqueKey = "StationLayer";
 
    public override void Dispose()
    {
        if (markerOverlay.FeatureSource != null)
            markerOverlay.FeatureSource.Close();
    }

     public override Overlay GetOverlay(bool google)
     {
         InMemoryFeatureSource inMemorySource = new InMemoryFeatureSource(new FeatureSourceColumn[] { new FeatureSourceColumn("Name"), new FeatureSourceColumn("RailwayNumber"), new FeatureSourceColumn("StationNumber") });
         inMemorySource.Open();
         using (MapLayersDataContext data = new MapLayersDataContext())
         {
             List<stationLayer> stations;
             switch (LayersManager.Settings.UserSetting.StationsFilter)
             {
                 case "pps":
                     stations = data.stationLayers.Where(s => s.Pps).ToList();
                     break;
                 case "klm":
                     stations = data.stationLayers.Where(s => s.Klm).ToList();
                     break;
                 case "dium":
                     stations = data.stationLayers.Where(s => s.Dium).ToList();
                     break;
                 default:
                     stations = data.stationLayers.ToList();
                     break;
             }

             foreach (stationLayer station in stations)
             {
                 string[] values = { "Name:" + station.Name, "RailwayNumber:" + station.RailwayNumber, "StationNumber:" + station.StationNumber };
                 Feature feature = new Feature(station.WKB_Geometry.ToArray(), station.oid.ToString(), values);

                 inMemorySource.InternalFeatures.Add(feature);
             }
         }

         if (google)
             inMemorySource.Projection = Projection;
         
         markerOverlay.FeatureSource = inMemorySource;

         WebImage image = new WebImage(String.Format("Images/Marks/{0}.png", LayersManager.Settings.UserSetting.IconStation), 16, 16, 0f, -16f);

         PropertyInfo zoomProperty = typeof(MarkerZoomLevelSet).GetProperty(String.Format("ZoomLevel{0:00}", LayersManager.Settings.UserSetting.ShowStationsFrom));
         MarkerZoomLevel zoomLevel = (MarkerZoomLevel)zoomProperty.GetValue(markerOverlay.ZoomLevelSet, null);
         zoomLevel.DefaultMarkerStyle.WebImage = image;
         zoomLevel.DefaultMarkerStyle.Popup.ContentHtml = "<span>&nbsp;[#RailwayNumber#]-[#StationNumber#]&nbsp;[#Name#]&nbsp;</span>";
         zoomLevel.DefaultMarkerStyle.Popup.AutoSize = true;
         zoomLevel.DefaultMarkerStyle.Popup.BackgroundColor = GeoColor.StandardColors.White;
         zoomLevel.DefaultMarkerStyle.Popup.BorderColor = GeoColor.StandardColors.Black;
         zoomLevel.DefaultMarkerStyle.Popup.BorderWidth = 1;
         zoomLevel.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                 

         inMemorySource.Close();
         return markerOverlay;
     }

     public string GetStationInfo(string featureId)
     {
         stationLayer station;
         using (MapLayersDataContext data = new MapLayersDataContext())
         {
             station = data.stationLayers.SingleOrDefault(s => s.oid == int.Parse(featureId));
         }
         if (station != null)
         {
             StationDiumInfo diumStation = CatalogueData.GetDiumStation(RailwaysUtils.FromNumber(station.RailwayNumber), station.StationNumber);
             string returnString = String.Format("<img src=\"Images/station.png\" alt=\"\"/>&nbsp;<b>{0}-{1}</b><div style=\"font-size: 90%\">{2}</div>", station.RailwayNumber, station.StationNumber, station.Name);
             if (diumStation != null)
             {
                 string[] codes = diumStation.Codes.Split(',');
                 foreach (string code in codes)
                 {
                     if (code == String.Empty)
                         continue;
                     returnString += String.Format("<p style=\"font-size: 90%\">{0}</p>", CatalogueData.GetStationInfo(RailwaysUtils.FromNumber(station.RailwayNumber), code, Jerid.Web.Common.Language.Czech));
                 }
             }

             return returnString;
         }
         else
             return String.Empty;
     }

    
}
